window.Gleam.initSearch([{"doc":"gond","title":"gond","content":"# Gond 🔠 · `cond` for Gleam\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-gond/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-gond&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/gond)](https://hex.pm/packages/gond)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![JavaScript Compatible](https://img.shields.io/badge/target-javascript-f3e155)](https://en.wikipedia.org/wiki/JavaScript)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gond/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n[![CI Test](https://github.com/inoas/gleam-gond/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-gond/actions/workflows/test.yml)\n\n&lt;br&gt;\n&lt;br&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;i&gt;\n    Think of a &lt;a href=&quot;https://en.wikipedia.org/wiki/Gondola_lift&quot;&gt;gondola lift&lt;/a&gt; ride, where you can hop off at any station.\n  &lt;/i&gt;\n&lt;/p&gt;\n\n&lt;br&gt;\n\n## Installation\n\n```sh\ngleam add gond@1\n```\n\n## Examples\n\n```gleam\nimport gleam/int\nimport gleam/io\nimport gleam/string\nimport gond.{\n  cond as cond, return as return, run as run, when as when, where as where,\n}\n\npub fn example() {\n  cond(\n    branches: [\n      when(fn() { int.random(3) == 1 }) |&gt; run(fn() { &quot;Heads!&quot; }),\n      where(int.random(3) == 2) |&gt; run(fn() { &quot;Tails!&quot; }),\n      when(fn() { True }) |&gt; return(&quot;This always occurs!&quot;),\n      where(False) |&gt; return(&quot;This is never the fact!&quot;),\n    ],\n    default: fn() { &quot;Lost the coin?&quot; },\n  )\n}\n\npub fn main() {\n  example() |&gt; string.inspect |&gt; io.println\n}\n\n```\n\n```shell\ngleam run --module gond/internal/usage_examples\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gond&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## Inspiration\n\nElixir&#39;s [`cond` macro](https://hexdocs.pm/elixir/case-cond-and-if.html#cond).\n","url":"index.html"},{"doc":"gond","title":"Branch","content":"pub opaque type Branch(a)\n Represents a branch of a conditional expressions.\n\n\nSynonyms:\ngond.Branch\ngond Branch","url":"gond.html#Branch"},{"doc":"gond","title":"Condition","content":"pub opaque type Condition\n Represents a condition that can be evaluated lazily or eagerly,\n\n\nSynonyms:\ngond.Condition\ngond Condition","url":"gond.html#Condition"},{"doc":"gond","title":"Consequence","content":"pub opaque type Consequence(a)\n Represents a condition that can be evaluated lazily or eagerly,\n\n\nSynonyms:\ngond.Consequence\ngond Consequence","url":"gond.html#Consequence"},{"doc":"gond","title":"cond","content":"pub fn cond(\n  branches branches: List(Branch(a)),\n  default alternative_fun: fn() -&gt; a,\n) -&gt; a\n Executes a list of branches and returns the consequence of the first branch\n that evaluates to true.\n\n If no branch evaluates to true, the default alternative function is executed.\n\nSynonyms:\ngond.cond\ngond cond","url":"gond.html#cond"},{"doc":"gond","title":"return","content":"pub fn return(\n  on condition: Condition,\n  consequence consequence: a,\n) -&gt; Branch(a)\n Sets a literal consequence to return if a previous condition evaludated to\n true.\n\nSynonyms:\ngond.return\ngond return","url":"gond.html#return"},{"doc":"gond","title":"run","content":"pub fn run(\n  on condition: Condition,\n  consequence consequence_fun: fn() -&gt; a,\n) -&gt; Branch(a)\n Sets a consequence to run if a previous condition evaludated to true.\n\nSynonyms:\ngond.run\ngond run","url":"gond.html#run"},{"doc":"gond","title":"when","content":"pub fn when(given condition_fun: fn() -&gt; Bool) -&gt; Condition\n Creates a condition that evaluates to true if the given function returns\n true.\n\nSynonyms:\ngond.when\ngond when","url":"gond.html#when"},{"doc":"gond","title":"where","content":"pub fn where(given condition: Bool) -&gt; Condition\n Creates a condition that holds a literal boolean value.\n\nSynonyms:\ngond.where\ngond where","url":"gond.html#where"},{"doc":"gond","title":"gond","content":" 🔠 Multi-branch conditional expressions for Gleam\n","url":"gond.html"}]);